@@ -12,6 +12,8 @@
 #ifndef _SPACING_H
 #define _SPACING_H
 
+#include <stdio.h>
+
 ///
 class Spacing {
 public:
@@ -62,6 +64,13 @@ public:
 		}
 	}
 	///
+	void set(Spacing::Space sp, char const* val)
+	{
+		float fval;
+		sscanf(val,"%f",&fval);
+		set(sp,fval);
+	}
+	///
 	void writeFile(FILE *file);
 	///
 	friend bool operator!=(Spacing const &a, Spacing const &b)
