@@ -39,11 +39,13 @@ public:
 	///
 	Buffer* newBuffer(LString const &s, LyXRC *, bool =false);
 private:
-	/** The max number of buffers there are possible to have
-	  loaded at the same time. (this only applies when we use an
-	  array)
-	  */
-	enum{ NUMBER_OF_BUFFERS = 50 };
+	enum {
+		/** The max number of buffers there are possible to have
+		    loaded at the same time. (this only applies when we use an
+		    array)
+		*/
+		NUMBER_OF_BUFFERS = 50
+	};
 	
 	/** The Bufferlist is currently implemented as a static array.
 	  The buffers are new'ed and deleted as reqested.
@@ -129,8 +131,8 @@ public:
 	 */
 	void makePup(int);
 
-	/** Later with multiple frames this should not be here.
-	 */
+	///** Later with multiple frames this should not be here.
+	// */
 	//Buffer* switchBuffer(Buffer *from, int);
 
 	///
@@ -169,5 +171,4 @@ private:
 	list_state _state;
 };
 
-
 #endif
