@@ -26,9 +26,9 @@
 class InsetLOA: public InsetCommand {
 public:
 	///
-	InsetLOA(): InsetCommand("listofalgorithms") { }
+	InsetLOA(): InsetCommand("listofalgorithms") {}
 	///
-	InsetLOA(Buffer *b): InsetCommand("listofalgorithms"),owner(b){};
+	InsetLOA(Buffer *b): InsetCommand("listofalgorithms"),owner(b) {}
         ///
 	void Validate(LaTeXFeatures &features) const;
         ///
