@@ -26,9 +26,9 @@
 class InsetLOT: public InsetCommand {
 public:
 	///
-	InsetLOT(): InsetCommand("listoftables") { }
+	InsetLOT(): InsetCommand("listoftables") {}
 	///
-	InsetLOT(Buffer *b): InsetCommand("listoftables"), owner(b){};
+	InsetLOT(Buffer *b): InsetCommand("listoftables"), owner(b) {}
         ///
         Inset* Clone() { return new InsetLOT(owner); }
     	///
