@@ -26,23 +26,25 @@
 class InsetTOC: public InsetCommand {
 public:
 	///
-	InsetTOC(): InsetCommand("tableofcontents") { }
+	InsetTOC(): InsetCommand("tableofcontents") {}
 	///
-	InsetTOC(Buffer *b): InsetCommand("tableofcontents"),owner(b){};
+	InsetTOC(Buffer *b): InsetCommand("tableofcontents"),owner(b){}
         ///
         Inset* Clone() { return new InsetTOC(owner); }
     	///
 	LString getScreenLabel() const { return _("Table of Contents"); }
-        
-	//void Edit(int, int);
+	/// On edit, we open the TOC pop-up
+	void Edit(int, int);
         ///
 	unsigned char Editable() const {
-		return 0; // not yet
+		return 1;
 	}
 	///
 	bool Display() const { return true; }
 	///
 	Inset::Code LyxCode() const { return Inset::TOC_CODE; }
+	///
+	int Linuxdoc(LString &file);
 private:
 	///
 	Buffer *owner;
