@@ -96,8 +96,9 @@ public:
 	
 	/** set font over selection and make a total rebreak of those
 	  paragraphs.
+	  toggleall defaults to false.
 	  */
-	void SetFont(LyXFont font);
+	void SetFont(LyXFont font, bool toggleall=false);
 	
 	/** deletes and inserts again all paragaphs between the cursor
 	  and the specified par .The Cursor is needed to set the refreshing
@@ -109,7 +110,7 @@ public:
 	void RedoParagraph();
 	
 	///
-	void ToggleFree(LyXFont font);
+	void ToggleFree(LyXFont font,bool toggleall=false);
 	
 	/** recalculates the heights of all previous rows of the
 	    specified paragraph.  needed, if the last characters font
@@ -263,12 +264,11 @@ public:
 	void DeleteLineForward();
 	///
 	int SelectWordWhenUnderCursor();
-	///
-	void UpcaseWord();
-	///
-	void LowcaseWord();
-	///
-	void CapitalizeWord();
+	/// Change the case of the word at cursor position
+	/** action is 0 for lower case, 1 for capitalization and 2 for
+	    uppercase. 
+	 */
+	void ChangeWordCase(int action);
 
 	/** returns a printed row in a pixmap. The y value is needed to
 	  decide, wether it is selected text or not. This is a strange
@@ -443,6 +443,8 @@ public:
         bool IsEmptyTableRow(LyXCursor *cursor);
         ///
         bool IsEmptyTableCell();
+        ///
+        void toggleAppendix();
 
 private:
 	///
